import { DataSource } from 'apollo-datasource';
import type { JobCounts, JobStatus, JobId, Job } from 'bull';
import { CreateJobInput, JobDataSearchInput, MutationCleanQueueArgs, MutationCloseQueueArgs, MutationDiscardJobArgs, MutationEmptyQueueArgs, MutationLogArgs, MutationMoveJobToCompletedArgs, MutationMoveJobToFailedArgs, MutationPromoteJobArgs, MutationRemoveJobArgs, MutationRemoveJobsArgs, MutationRemoveJobsByPatternArgs, MutationResumeQueueArgs, MutationRetryJobArgs, MutationRetryJobsArgs, MutationUpdateJobDataArgs, OrderEnum } from '../../../typings/gql';
import { Maybe } from '../../../typings/utils';
import redisInfo from 'redis-info';
import { BullMonitorQueue as Queue } from '../../../queue';
declare type Config = {
    textSearchScanCount?: number;
};
export declare enum ErrorEnum {
    QUEUE_NOT_FOUND = "Queue not found",
    JOB_NOT_FOUND = "Job not found",
    DATA_SEARCH_STATUS_REQUIRED = "Job status is required for data search",
    BAD_OFFSET = "Offset should be >= 0",
    BAD_LIMIT = "Limit should be >= 1"
}
export declare class BullDataSource extends DataSource {
    private _queues;
    private _config;
    private _queuesMap;
    constructor(_queues: Queue[], _config: Config);
    private _convertQueuesToMap;
    private _throwInternalError;
    private _throwQueueNotFound;
    private _throwJobNotFound;
    getQueueByName(name: string, throwIfNotFound?: boolean): Queue | undefined;
    getQueueById(id: string, throwIfNotFound?: boolean): Queue | undefined;
    getQueues(): Queue[];
    getQueueJobs({ queue, limit, offset, status, id, ids, order, dataSearch, }: {
        limit?: number;
        offset?: number;
        dataSearch?: JobDataSearchInput;
        id?: string;
        order?: OrderEnum;
        ids?: string[];
        status?: JobStatus;
        queue: string;
    }): Promise<Job<any>[]>;
    private _filterJobs;
    getJob(queueId: string, id: JobId, throwIfNotFound?: boolean): Promise<Job<any> | null>;
    extractJobProcessingTime(job: Job): number;
    getQueueJobsCounts(id: string): Promise<Maybe<JobCounts>>;
    getQueueFailedCount(id: string): Promise<Maybe<number>>;
    getQueueCompletedCount(id: string): Promise<Maybe<number>>;
    getQueueDelayedCount(id: string): Promise<Maybe<number>>;
    getQueueActiveCount(id: string): Promise<Maybe<number>>;
    getQueueWaitingCount(id: string): Promise<Maybe<number>>;
    getQueuePausedCount(id: string): Promise<Maybe<number>>;
    getQueueWaitingOrDelayedJobsCount(id: string): Promise<Maybe<number>>;
    getRedisInfo(): Promise<redisInfo.RedisInfo | null>;
    createJob({ queue: queueId, name, data, options, }: CreateJobInput): Promise<Job<any>>;
    removeJobsByPattern(args: MutationRemoveJobsByPatternArgs): Promise<boolean>;
    pauseQueue(id: string): Promise<Queue>;
    cleanQueue(args: MutationCleanQueueArgs): Promise<Job<any>[]>;
    emptyQueue(args: MutationEmptyQueueArgs): Promise<Queue>;
    closeQueue(args: MutationCloseQueueArgs): Promise<Queue>;
    resumeQueue(args: MutationResumeQueueArgs): Promise<Queue>;
    promoteJob(args: MutationPromoteJobArgs): Promise<Job<any> | null>;
    discardJob(args: MutationDiscardJobArgs): Promise<Job<any> | null>;
    updateJobData(args: MutationUpdateJobDataArgs): Promise<Job<any> | null>;
    createJobLog(args: MutationLogArgs): Promise<Job<any> | null>;
    retryJob(args: MutationRetryJobArgs): Promise<Job<any> | null>;
    retryJobs(args: MutationRetryJobsArgs): Promise<(Job<any> | null)[]>;
    removeJobById(args: MutationRemoveJobArgs): Promise<Job<any> | null>;
    removeJobs(args: MutationRemoveJobsArgs): Promise<(Job<any> | null)[]>;
    moveJobToCompleted(args: MutationMoveJobToCompletedArgs): Promise<Job<any> | null>;
    moveJobToFailed(args: MutationMoveJobToFailedArgs): Promise<Job<any> | null>;
}
export {};
